@@ -4,8 +4,6 @@ from __future__ import annotations
 from pygerber.parser.blender.apertures.arc_mixin import ArcUtilMixinBlender
 from pygerber.parser.blender.apertures.util import BlenderUtilMethods
 from pygerber.renderer.aperture.custom import CustomAperture
-from pygerber.renderer.spec import ArcSpec
-from pygerber.renderer.spec import LineSpec
 
 
 class BlenderCustom(ArcUtilMixinBlender, BlenderUtilMethods, CustomAperture):
