@@ -2,9 +2,8 @@
 from __future__ import annotations
 
 from pygerber.parser.blender.apertures.rectangle import BlenderRectangle
-from pygerber.renderer.spec import ArcSpec
-from pygerber.renderer.spec import FlashSpec
-from pygerber.renderer.spec import LineSpec
+
+# from pygerber.renderer.spec import ArcSpec, FlashSpec, LineSpec
 
 
 class BlenderObround(BlenderRectangle):
