@@ -4,9 +4,7 @@ from __future__ import annotations
 from pygerber.parser.blender.apertures.arc_mixin import ArcUtilMixinBlender
 from pygerber.parser.blender.apertures.flash_mixin import FlashUtilMixin
 from pygerber.renderer.aperture.polygon import PolygonAperture
-from pygerber.renderer.spec import ArcSpec
-from pygerber.renderer.spec import FlashSpec
-from pygerber.renderer.spec import LineSpec
+from pygerber.renderer.spec import ArcSpec, FlashSpec, LineSpec
 
 
 class BlenderPolygon(ArcUtilMixinBlender, FlashUtilMixin, PolygonAperture):
