@@ -9,9 +9,7 @@ from PyR3.shortcut.transform import Transform
 from pygerber.parser.blender.apertures.arc_mixin import ArcUtilMixinBlender
 from pygerber.parser.blender.apertures.flash_mixin import FlashUtilMixin
 from pygerber.renderer.aperture.rectangular import RectangularAperture
-from pygerber.renderer.spec import ArcSpec
-from pygerber.renderer.spec import FlashSpec
-from pygerber.renderer.spec import LineSpec
+from pygerber.renderer.spec import ArcSpec, FlashSpec, LineSpec
 
 
 class BlenderRectangle(ArcUtilMixinBlender, FlashUtilMixin, RectangularAperture):
