@@ -5,9 +5,7 @@ import os
 
 from PyR3.shortcut.io import export_to
 
-from pygerber.API3D import render_from_json
-from pygerber.API3D import render_from_toml
-from pygerber.API3D import render_from_yaml
+from pygerber.API3D import render_from_json, render_from_toml, render_from_yaml
 from pygerber.mathclasses import format_bytes
 from pygerber.parser.blender.api import _skip_next_render
 
