@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import annotations
 
-from abc import ABC
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -10,9 +9,7 @@ if TYPE_CHECKING:
 
 from pygerber.mathclasses import BoundingBox
 from pygerber.renderer.arc_util_mixin import ArcUtilMixin
-from pygerber.renderer.spec import ArcSpec
-from pygerber.renderer.spec import FlashSpec
-from pygerber.renderer.spec import LineSpec
+from pygerber.renderer.spec import ArcSpec, FlashSpec, LineSpec
 from pygerber.tokens.add import ADD_Token
 
 
