@@ -2,8 +2,7 @@
 from dataclasses import dataclass
 from typing import Type
 
-from .aperture import Aperture
-from .aperture import RegionApertureManager
+from .aperture import Aperture, RegionApertureManager
 
 
 @dataclass
