@@ -11,8 +11,7 @@ import re
 from pygerber.exceptions import EndOfStream
 from pygerber.validators.basic import String
 
-from .token import Deprecated
-from .token import Token
+from .token import Deprecated, Token
 
 
 class EndOfStream_Token(Token):
