@@ -8,8 +8,7 @@ if TYPE_CHECKING:
 
 import re
 
-from pygerber.validators.basic import Float
-from pygerber.validators.basic import String
+from pygerber.validators.basic import Float, String
 
 from .token import Token
 
